@@ -25,6 +25,7 @@
  */
 
 #include "platform.h"
+#include <limits.h>
 #include "internal.h"
 #include "md5.h"
 #include "base64.h"
@@ -296,7 +297,7 @@ lookup_sub_value(char *dest,
 static int
 check_nonce_nc (struct MHD_Connection *connection,
 		const char *nonce,
-		unsigned int nc)
+		unsigned long int nc)
 {
   uint32_t off;
   uint32_t mod;
@@ -447,6 +448,7 @@ MHD_digest_auth_check(struct MHD_Connection *connection,
 {
   size_t len;
   const char *header;
+  char *end;
   char nonce[MAX_NONCE_LENGTH];
   char cnonce[MAX_NONCE_LENGTH];
   char qop[15]; /* auth,auth-int */
@@ -459,7 +461,7 @@ MHD_digest_auth_check(struct MHD_Connection *connection,
   uint32_t nonce_time;
   uint32_t t;
   size_t left; /* number of characters left in 'header' for 'uri' */
-  unsigned int nci;
+  unsigned long int nci;
 
   header = MHD_lookup_connection_value(connection,
 				       MHD_HEADER_KIND,
@@ -544,9 +546,12 @@ MHD_digest_auth_check(struct MHD_Connection *connection,
 	 ( (0 != strcmp (qop, "auth")) && 
 	   (0 != strcmp (qop, "")) ) ||
 	 (0 == lookup_sub_value(nc, sizeof (nc), header, "nc"))  ||
-	 (1 != sscanf (nc, "%u", &nci)) ||
 	 (0 == lookup_sub_value(response, sizeof (response), header, "response")) )
       return MHD_NO;
+    nci = strtoul (nc, &end, 10);
+    if ( ('\0' != *end) ||
+	 ( (LONG_MAX == nci) && (errno == ERANGE) ) )
+      return MHD_NO; /* invalid nonce */
     
     /*
      * Checking if that combination of nonce and nc is sound
